@echo off
rem @(#)23  1.4  src/hc/report/operational/db2_8.1/jar/col_report.bat, hc.report, scmweb, 041213a  12/3/04  14:29:53
rem
rem  COMPONENT_NAME:  hc.report
rem
rem  FUNCTION:
rem    This file is used to create the Java stored procedure for DB2 8.1
rem
rem  Licensed Materials - Property of IBM Corporation
rem
rem  5724-F82
rem
rem  (C) Copyright IBM Corp. 2004
rem  All Rights Reserved
rem
rem  US Government Users Restricted Rights - Use, duplication or
rem  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem

rem Change value of TARGET_USERID to the intended user name.
rem Change value of TARGET_PASSWORD to the correct password.
rem Change value of TARGET_DATABASE to the target database name.
rem Change value of FILE_PATH to the directory path where you have extracted jar file.

setlocal
goto START

:USAGE
echo.
echo Usage: col_report.bat -u ^<user^> -p ^<password^> [-a ^<database alias^>] [-d ^<directory^>]
echo Where: 
echo   user           : Database user name. This parameter is required.
echo   password       : Database password. This parameter is required.
echo   database alias : Local database alias. Default is 'JAC'.
echo   directory      : Location of JAR file containing the Java stored procedure. Default is the current directory.
echo.
echo   Run the script using the DB2 Command Line Processor (CLP).  If a parameter contains spaces or special characters, enclose the parameter in quotation marks (").
echo.
goto NOOP


:START
if [%1]==[] (call :USAGE && goto END)

rem
rem -- Check whether the script is being run from DB2 CLP. 
rem -- DB2CLP environment variable is set by the DB2 CLP. 
rem
:CHECK_DB2_CLP
if "%DB2CLP%"=="" (echo The script must be run from the DB2 Command Line Processor ^(CLP^). && echo. && goto END)

:LOOP
if [%1]==[] goto CONTINUE
	set option=%1
	if "%option%"=="-u" (
		if not [%2]==[] (
			set TARGET_USERID=%~2
		) else (
			echo The required value for the -u option was not specified. && call :USAGE && goto END
		)
	) else (
	if "%option%"=="-p" (
		if not [%2]==[] (
			set TARGET_PASSWORD=%~2
		) else (
			echo The required value for the -p option was not specified. && call :USAGE && goto END
		)
	) else (
	if "%option%"=="-a" (
		if not [%2]==[] (
			set TARGET_DATABASE=%~2
		) else (
			echo The required value for the -a option was not specified. && call :USAGE && goto END
		)
	) else (
	if "%option%"=="-d" (
		if not [%2]==[] (
			set FILE_PATH=%~2
		) else (
			echo The required value for the -d option was not specified. && call :USAGE && goto END
		)
	) else (
		echo Unrecognized option: %option%
		call :USAGE
		goto END
	))))
	
:NEXT_PARAM
	shift
	shift
goto LOOP

:CONTINUE

set TARGET_SCHEMA=JAC_SYS

rem -- Set default value of target database if not set
if not defined TARGET_DATABASE (set TARGET_DATABASE=JAC)

rem -- Set default value of location of Jar file if not set
if not defined FILE_PATH (set FILE_PATH=%cd%)

rem -- Check user id
:CHECK_TARGET_USERID
if "%TARGET_USERID%"=="" (
	echo The required -u ^<user^> parameter is missing.
	call :USAGE
	goto END
)

rem -- Check user password
:CHECK_TARGET_PASSWORD
if "%TARGET_PASSWORD%"=="" (
	echo The required -p ^<password^> parameter is missing.
	call :USAGE
	goto END
)

rem -- Check existence of jar file
:CHECK_JAR_EXISTENCE
if not exist "%FILE_PATH%\JAC_SYS_SCHEMA_COL_REPORT.jar" (
	echo The JAC_SYS_SCHEMA_COL_REPORT.jar file was not found in the %FILE_PATH% directory 
	echo.
	goto END
)


:DB2_PROCESS
db2 connect to %TARGET_DATABASE% user %TARGET_USERID% using %TARGET_PASSWORD%
if not "%ERRORLEVEL%"=="0" (echo An error occurred while establishing a connection to the database. && goto END)

db2 DROP PROCEDURE %TARGET_SCHEMA%.COL_REPORT > NUL


rem --------------------------------------------------------------------
rem In DB2 8.1 FixPack 0, there is a defect that causes sqlj.remove_jar() 
rem and sqlj.install_jar() functions to return exit code 2 even if the 
rem call is successful. Since this errorlevel is set incorrectly, we'll 
rem reset it to 0. 
rem
rem This problem has not been seen in DB2 8.1 FixPack 4.
rem ---------------------------------------------------------------------

db2 call sqlj.remove_jar("%TARGET_SCHEMA%.COL_REPORT") > NUL
set ERRORLEVEL=0

db2 call sqlj.install_jar('file:///%FILE_PATH%\JAC_SYS_SCHEMA_COL_REPORT.jar',"%TARGET_SCHEMA%.COL_REPORT")
if not "%ERRORLEVEL%"=="0" (
	echo An error occurred while installing the JAR file. && goto RESET_CONNECTION
)

db2 CREATE PROCEDURE %TARGET_SCHEMA%.COL_REPORT (  ) EXTERNAL NAME '%TARGET_SCHEMA%.COL_REPORT:COLLECTOR_RUN.collector_run' SPECIFIC %TARGET_SCHEMA%.COL_REPORT RESULT SETS 1 LANGUAGE JAVA PARAMETER STYLE JAVA NOT DETERMINISTIC FENCED NO DBINFO NULL CALL MODIFIES SQL DATA
if not "%ERRORLEVEL%"=="0" (echo An error occurred while creating the Java stored procedure. && goto RESET_CONNECTION)

db2 call sqlj.refresh_classes ( void ) > NUL

:RESET_CONNECTION
db2 connect reset > NUL


:END
endlocal
@echo on

:NOOP
