#!/bin/sh

#  @(#)24 1.4 src/hc/report/operational/db2_8.1/jar/col_report.sh, hc.report, scmweb, 041213a 12/3/04 15:21:04
#
# COMPONENT_NAME:  hc.report
#
# FUNCTION:
#   This file is used to create the Java stored procedure for DB2 8.1 
#
# IBM Confidential
# OCO Source Materials
#
# 5724-F82
#
# (C) Copyright IBM Corp. 2004.
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the US Copyright Office.
#
#

# Change value of TARGET_USERID to the intended user name.
# Change value of TARGET_PASSWORD to the correct password.
# Change value of TARGET_DATABASE to the target database name.
# Change value of FILE_PATH to the directory path where you have extracted jar file.

USAGE="
Usage: col_report.sh -u <user> -p <password> [-a <database alias>] [-d <directory>]
Where: 
  user           : Database user name. This parameter is required.
  password       : Database password. This parameter is required.
  database alias : Local database alias. Default is 'JAC'.
  directory      : Location of JAR file containing the Java stored procedure. Default is the current directory.
  
  Run the script as a valid DB2 user.  If a parameter contains spaces or special characters, enclose the parameter in quotation marks (\").
"

if [ $# -eq 0 ]
then
	echo "$USAGE"
	exit 1
fi

# -- Check if the user has logged in as DB2 user. The environment variable DB2INSTANCE is set during logging in.
if [ -z "$DB2INSTANCE" ]
then
	echo "The script must be run by a valid DB2 user."
	echo
	exit 2
fi

while getopts a:u:p:d: OPTION ; 
do
    case "$OPTION" in
        u) TARGET_USERID="$OPTARG" ;;
        p) TARGET_PASSWORD="$OPTARG";;
     	a) TARGET_DATABASE="$OPTARG" ;;
        d) FILE_PATH="$OPTARG";; 
	*) echo "$USAGE" ;
           	exit 3 
           	;;
    esac
done
CWD=`pwd`


TARGET_SCHEMA=JAC_SYS

# -- Set default value of target database if not set
TARGET_DATABASE=${TARGET_DATABASE:-JAC}

# -- Set default value of location of Jar file if not set
FILE_PATH=${FILE_PATH:-$CWD}


# -- Check user id
if [ -z "$TARGET_USERID" ]
then
	echo "The required -u <user> parameter is missing."
	echo "$USAGE"
	exit 4
fi

# -- Check user password
if [ -z "$TARGET_PASSWORD" ]
then
	echo "The required -p <password> parameter is missing."
	echo "$USAGE"
	exit 5
fi


# -- Check jar existence
if [ ! -f "$FILE_PATH/JAC_SYS_SCHEMA_COL_REPORT.jar" ]
then
	echo "The JAC_SYS_SCHEMA_COL_REPORT.jar file was not found in the $FILE_PATH directory."
	exit 6
fi

db2 "connect to $TARGET_DATABASE user $TARGET_USERID using $TARGET_PASSWORD"
if [ $? -ne 0 ]
then
	echo "An error occurred while establishing a connection to the database."
	exit 7
fi

db2 "DROP PROCEDURE $TARGET_SCHEMA.COL_REPORT" > /dev/null

# ---------------------------------------------------------------------
# In DB2 8.1 FixPack 0, there is a defect that causes sqlj.remove_jar() 
# and sqlj.install_jar() functions to return exit code 2 even if the 
# call is successful. Since this errorlevel is set incorrectly, we'll
# ignore this check for sqlj.install_jar(). 
#
# This problem has not been seen in DB2 8.1 FixPack 4.
# ---------------------------------------------------------------------

db2 "call sqlj.remove_jar("$TARGET_SCHEMA.COL_REPORT")" > /dev/null

db2 "call sqlj.install_jar('file:$FILE_PATH/JAC_SYS_SCHEMA_COL_REPORT.jar',"$TARGET_SCHEMA.COL_REPORT")"

if [ $? -ne 0 -a $? -ne 2 ]
then
	echo "An error occurred while installing the JAR file."
	db2 "connect reset"
	exit 8
fi

db2 "CREATE PROCEDURE $TARGET_SCHEMA.COL_REPORT (  ) EXTERNAL NAME '$TARGET_SCHEMA.COL_REPORT:COLLECTOR_RUN.collector_run' SPECIFIC $TARGET_SCHEMA.COL_REPORT RESULT SETS 1 LANGUAGE JAVA PARAMETER STYLE JAVA NOT DETERMINISTIC FENCED NO DBINFO NULL CALL MODIFIES SQL DATA"
if [ $? -ne 0 ]
then
	echo "An error occurred while creating the Java stored procedure."
	db2 "connect reset"
	exit 9
fi

db2 "call sqlj.refresh_classes ( void )" > /dev/null

db2 "connect reset" > /dev/null
